<?php

/**
  * SquirrelMail Templates Plugin
  * Copyright (c) 2005 Paul Lesneiwski <pdontthink@angrynerds.com>
  * Copyright (c) 2003-2005 Ryan Rubley <ryan@morpheussoftware.net>
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * @package plugins
  * @subpackage templates
  *
  */


function squirrelmail_plugin_init_templates () {
    global $squirrelmail_plugin_hooks;

    $squirrelmail_plugin_hooks['compose_button_row']['templates'] =
        'plugin_templates_compose_button_row_stub';
    $squirrelmail_plugin_hooks['optpage_register_block']['templates'] =
        'plugin_templates_optpage_register_block_stub';
}

/** @ignore */
if (!defined('SM_PATH')) 
    define('SM_PATH', '../');

function templates_version() {
	return '1.2-1.4.0';
}

function plugin_templates_compose_button_row_stub() {
    include_once(SM_PATH . 'plugins/templates/functions.php');
    plugin_templates_compose_button_row();
}

function plugin_templates_optpage_register_block_stub() {
    include_once(SM_PATH . 'plugins/templates/functions.php');
    plugin_templates_optpage_register_block();
}

?>
